@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 import os
 import shutil
 from subprocess import run
@@ -8,14 +6,29 @@ import click
 
 import motion
 
-MOTION_HOME = os.environ.get("MOTION_HOME", os.path.expanduser("~/.cache/motion"))
-
 
 @click.group()
 def motioncli() -> None:
     pass
 
 
+@motioncli.command("example")
+@click.option(
+    "--name",
+    prompt="Example application name",
+    help="One of the example applications to create. Can be: 'cooking'.",
+)
+@click.option(
+    "--author",
+    prompt="Your name",
+    help="Author name.",
+)
+def example(name: str, author: str) -> None:
+    """Creates a new application from an example."""
+    motion.create_example_app(name, author)
+    click.echo("Created a project successfully.")
+
+
 @motioncli.command("create")
 @click.option(
     "--name",
@@ -29,32 +42,7 @@ def motioncli() -> None:
 )
 def create(name: str, author: str) -> None:
     """Creates a new application."""
-    # Return error if name is not valid
-    name = name.strip().lower()
-    if len(name.split(" ")) > 1:
-        click.echo("Name cannot contain spaces.")
-        return
-
-    if os.path.exists(name):
-        click.echo(f"Directory {name} already exists.")
-        return
-
-    # Copy over the example project
-    shutil.copytree(os.path.join(os.path.dirname(__file__), "exampleproj"), name)
-
-    # Create store setup file
-    with open(os.path.join(name, "mconfig.py"), "w") as f:
-        f.write(
-            open(
-                os.path.join(
-                    os.path.dirname(__file__),
-                    "exampleproj/mconfig.py",
-                ),
-            )
-            .read()
-            .replace("{0}", name)
-            .replace("{1}", author)
-        )
+    motion.create_app(name, author)
 
     click.echo("Created a project successfully.")
 
@@ -97,6 +85,7 @@ def serve(host: str, port: int, logging_level: str) -> None:
 def clear(name: str) -> None:
     """Removes the datastore for the given application."""
     # Remove directory at name
+    MOTION_HOME = os.environ.get("MOTION_HOME", os.path.expanduser("~/.cache/motion"))
     dirname = os.path.join(MOTION_HOME, "datastores", name)
     if not os.path.exists(dirname):
         click.echo(f"Application {name} does not exist.")
